aboutsummaryrefslogtreecommitdiffstats
path: root/sgsnemu/cmdline.h
diff options
context:
space:
mode:
authorHarald Welte <laforge@gnumonks.org>2010-05-04 11:13:56 +0200
committerHarald Welte <laforge@gnumonks.org>2010-05-04 11:13:56 +0200
commit1b3e57701744ac33878fa129c087c1798fee4936 (patch)
tree625302939c9c508d3e16f60237a0879b81cfc12e /sgsnemu/cmdline.h
parent5701b0f6479603284f80d0277ae31d1099dce7ed (diff)
Use newer gengetopt which also frees memory
Taken from http://sourceforge.net/tracker/index.php?func=detail&aid=1811521&group_id=68956&atid=522957
Diffstat (limited to 'sgsnemu/cmdline.h')
-rw-r--r--sgsnemu/cmdline.h109
1 files changed, 94 insertions, 15 deletions
diff --git a/sgsnemu/cmdline.h b/sgsnemu/cmdline.h
index 834d73c..a15480d 100644
--- a/sgsnemu/cmdline.h
+++ b/sgsnemu/cmdline.h
@@ -1,55 +1,115 @@
/* cmdline.h */
-/* File autogenerated by gengetopt version 2.8 */
+/* File autogenerated by gengetopt version 2.17 */
-#ifndef _cmdline_h
-#define _cmdline_h
+#ifndef CMDLINE_H
+#define CMDLINE_H
+
+/* If we use autoconf. */
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */
-/* Don't define PACKAGE and VERSION if we use automake. */
-#ifndef PACKAGE
-#define PACKAGE ""
+#ifndef CMDLINE_PARSER_PACKAGE
+#define CMDLINE_PARSER_PACKAGE PACKAGE
#endif
-#ifndef VERSION
-#define VERSION ""
+#ifndef CMDLINE_PARSER_VERSION
+#define CMDLINE_PARSER_VERSION VERSION
#endif
struct gengetopt_args_info
{
+ const char *help_help; /* Print help and exit help description. */
+ const char *version_help; /* Print version and exit help description. */
int debug_flag; /* Run in debug mode (default=off). */
+ const char *debug_help; /* Run in debug mode help description. */
char * conf_arg; /* Read configuration file. */
+ char * conf_orig; /* Read configuration file original value given at command line. */
+ const char *conf_help; /* Read configuration file help description. */
char * pidfile_arg; /* Filename of process id file (default='./sgsnemu.pid'). */
+ char * pidfile_orig; /* Filename of process id file original value given at command line. */
+ const char *pidfile_help; /* Filename of process id file help description. */
char * statedir_arg; /* Directory of nonvolatile data (default='./'). */
+ char * statedir_orig; /* Directory of nonvolatile data original value given at command line. */
+ const char *statedir_help; /* Directory of nonvolatile data help description. */
char * dns_arg; /* DNS Server to use. */
+ char * dns_orig; /* DNS Server to use original value given at command line. */
+ const char *dns_help; /* DNS Server to use help description. */
char * listen_arg; /* Local interface. */
+ char * listen_orig; /* Local interface original value given at command line. */
+ const char *listen_help; /* Local interface help description. */
char * remote_arg; /* Remote host. */
+ char * remote_orig; /* Remote host original value given at command line. */
+ const char *remote_help; /* Remote host help description. */
int contexts_arg; /* Number of contexts (default='1'). */
+ char * contexts_orig; /* Number of contexts original value given at command line. */
+ const char *contexts_help; /* Number of contexts help description. */
int timelimit_arg; /* Exit after timelimit seconds (default='0'). */
+ char * timelimit_orig; /* Exit after timelimit seconds original value given at command line. */
+ const char *timelimit_help; /* Exit after timelimit seconds help description. */
int gtpversion_arg; /* GTP version to use (default='1'). */
+ char * gtpversion_orig; /* GTP version to use original value given at command line. */
+ const char *gtpversion_help; /* GTP version to use help description. */
char * apn_arg; /* Access point name (default='internet'). */
+ char * apn_orig; /* Access point name original value given at command line. */
+ const char *apn_help; /* Access point name help description. */
int selmode_arg; /* Selection mode (default='0x01'). */
+ char * selmode_orig; /* Selection mode original value given at command line. */
+ const char *selmode_help; /* Selection mode help description. */
char * imsi_arg; /* IMSI (default='240010123456789'). */
+ char * imsi_orig; /* IMSI original value given at command line. */
+ const char *imsi_help; /* IMSI help description. */
int nsapi_arg; /* NSAPI (default='0'). */
+ char * nsapi_orig; /* NSAPI original value given at command line. */
+ const char *nsapi_help; /* NSAPI help description. */
char * msisdn_arg; /* Mobile Station ISDN number (default='46702123456'). */
+ char * msisdn_orig; /* Mobile Station ISDN number original value given at command line. */
+ const char *msisdn_help; /* Mobile Station ISDN number help description. */
int qos_arg; /* Requested quality of service (default='0x0b921f'). */
+ char * qos_orig; /* Requested quality of service original value given at command line. */
+ const char *qos_help; /* Requested quality of service help description. */
int charging_arg; /* Charging characteristics (default='0x0800'). */
+ char * charging_orig; /* Charging characteristics original value given at command line. */
+ const char *charging_help; /* Charging characteristics help description. */
char * uid_arg; /* Login user ID (default='mig'). */
+ char * uid_orig; /* Login user ID original value given at command line. */
+ const char *uid_help; /* Login user ID help description. */
char * pwd_arg; /* Login password (default='hemmelig'). */
+ char * pwd_orig; /* Login password original value given at command line. */
+ const char *pwd_help; /* Login password help description. */
int createif_flag; /* Create local network interface (default=off). */
+ const char *createif_help; /* Create local network interface help description. */
char * net_arg; /* Network address for local interface. */
+ char * net_orig; /* Network address for local interface original value given at command line. */
+ const char *net_help; /* Network address for local interface help description. */
int defaultroute_flag; /* Create default route (default=off). */
+ const char *defaultroute_help; /* Create default route help description. */
char * ipup_arg; /* Script to run after link-up. */
+ char * ipup_orig; /* Script to run after link-up original value given at command line. */
+ const char *ipup_help; /* Script to run after link-up help description. */
char * ipdown_arg; /* Script to run after link-down. */
+ char * ipdown_orig; /* Script to run after link-down original value given at command line. */
+ const char *ipdown_help; /* Script to run after link-down help description. */
char * pinghost_arg; /* Ping remote host. */
- unsigned int pingrate_arg; /* Number of ping req per second (default='1'). */
- unsigned int pingsize_arg; /* Number of ping data bytes (default='56'). */
- unsigned int pingcount_arg; /* Number of ping req to send (default='0'). */
+ char * pinghost_orig; /* Ping remote host original value given at command line. */
+ const char *pinghost_help; /* Ping remote host help description. */
+ int pingrate_arg; /* Number of ping req per second (default='1'). */
+ char * pingrate_orig; /* Number of ping req per second original value given at command line. */
+ const char *pingrate_help; /* Number of ping req per second help description. */
+ int pingsize_arg; /* Number of ping data bytes (default='56'). */
+ char * pingsize_orig; /* Number of ping data bytes original value given at command line. */
+ const char *pingsize_help; /* Number of ping data bytes help description. */
+ int pingcount_arg; /* Number of ping req to send (default='0'). */
+ char * pingcount_orig; /* Number of ping req to send original value given at command line. */
+ const char *pingcount_help; /* Number of ping req to send help description. */
int pingquiet_flag; /* Do not print ping packet info (default=off). */
-
+ const char *pingquiet_help; /* Do not print ping packet info help description. */
+
int help_given ; /* Whether help was given. */
int version_given ; /* Whether version was given. */
int debug_given ; /* Whether debug was given. */
@@ -84,14 +144,33 @@ struct gengetopt_args_info
} ;
-int cmdline_parser (int argc, char * const *argv, struct gengetopt_args_info *args_info);
+extern const char *gengetopt_args_info_purpose;
+extern const char *gengetopt_args_info_usage;
+extern const char *gengetopt_args_info_help[];
+
+int cmdline_parser (int argc, char * const *argv,
+ struct gengetopt_args_info *args_info);
+int cmdline_parser2 (int argc, char * const *argv,
+ struct gengetopt_args_info *args_info,
+ int override, int initialize, int check_required);
+int cmdline_parser_file_save(const char *filename,
+ struct gengetopt_args_info *args_info);
void cmdline_parser_print_help(void);
void cmdline_parser_print_version(void);
-int cmdline_parser_configfile (char * const filename, struct gengetopt_args_info *args_info, int override);
+void cmdline_parser_init (struct gengetopt_args_info *args_info);
+void cmdline_parser_free (struct gengetopt_args_info *args_info);
+
+int cmdline_parser_configfile (char * const filename,
+ struct gengetopt_args_info *args_info,
+ int override, int initialize, int check_required);
+
+int cmdline_parser_required (struct gengetopt_args_info *args_info,
+ const char *prog_name);
+
#ifdef __cplusplus
}
#endif /* __cplusplus */
-#endif /* _cmdline_h */
+#endif /* CMDLINE_H */